======
rev_ai
======


.. image:: https://img.shields.io/travis/JDongian/rev_ai.svg
        :target: https://travis-ci.org/JDongian/rev_ai

.. image:: https://readthedocs.org/projects/rev-ai/badge/?version=latest
        :target: https://rev-ai.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Rev.ai makes speech applications easy to build!


* Free software: MIT license
* Documentation: https://rev-ai.readthedocs.io.
